/*
 * Copyright 2010 by Kappich Systemberatung Aachen
 * 
 * This file is part of de.bsvrz.pua.prot.
 * 
 * de.bsvrz.pua.prot is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.pua.prot is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.pua.prot.  If not, see <http://www.gnu.org/licenses/>.
 */

package de.bsvrz.pua.prot.data;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.pua.prot.util.ResultValue;

import java.util.List;

/**
 * Array-Ansicht auf ein Datum. Liefert skalierte Werte. Für unskalierte Werte existiert die abgeleitete Klasse {@link de.bsvrz.pua.prot.data.ProtocolUnscaledDataArrayView}.
 *
 * @author Kappich Systemberatung
 * @version $Revision: 0000 $
 */
class ProtocolDataArrayView extends AbstractArrayView{

	/**
	 * Daten-Objekt, auf das diese Ansicht zeigt
	 */
	protected AttributeProtocolData _attributeProtocolData;

	/**
	 * Array-Werte des Datums
	 */
	protected List<ResultValue> _arrayItems;

	/**
	 * Erstellt eine Array-Ansicht auf ein Datum
	 * @param attributeProtocolData Datum
	 */
	public ProtocolDataArrayView(final AttributeProtocolData attributeProtocolData) {
		_attributeProtocolData = attributeProtocolData;
		_arrayItems = _attributeProtocolData.getArrayItems();
	}

	@Override
	public Data.NumberValue getValue(final int itemIndex) {
		return getScaledValue(itemIndex);
	}

	public Data.NumberArray asUnscaledArray() {
		return new ProtocolUnscaledDataArrayView(_attributeProtocolData);
	}

	public final int getMaxCount() {
		return getLength();
	}

	public final int getLength() {
		return _arrayItems.size();
	}

	public final Data getItem(final int itemIndex) {
		return new AttributeProtocolData(_attributeProtocolData.getAttributeType(), _attributeProtocolData.getDataModel(), _arrayItems.get(itemIndex));
	}

	@Override
	public String toString() {
		return _arrayItems.toString();
	}
}
